import 'package:meta/meta.dart';

@immutable
abstract class CustomItemPageState {}

/// 骨架图状态
class CustomItemPageInitial extends CustomItemPageState {}

/// 数据加载成功
class CustomItemPageLoadedState extends CustomItemPageState {
  final List<Map<String, dynamic>> model;

  CustomItemPageLoadedState({this.model});
}

/// 初始化失败
class CustomItemPageInitErrorState extends CustomItemPageState {}

/// 下拉刷新成功
class CustomItemPageRefreshSuccessState extends CustomItemPageState {}

/// 下拉刷新失败
class CustomItemPageRefreshErrorState extends CustomItemPageState {}

/// 上拉更多成功
class CustomItemPageLoadSuccessState extends CustomItemPageState {}

/// 上拉更多失败
class CustomItemPageLoadErrorState extends CustomItemPageState {}

/// 其他错误
class CustomItemPageErrorState extends CustomItemPageState {}
